@@ -2,7 +2,7 @@
 # Copyright (c) 2024 Manuel Schneider
 
 """
-Translates text using the python package translators. See https://pypi.org/project/translators/
+Translates text using the python package [translators](https://pypi.org/project/translators/).
 """
 
 from locale import getdefaultlocale
@@ -12,8 +12,8 @@ from time import sleep
 from albert import *
 import translators as ts
 
-md_iid = "4.0"
-md_version = "2.2.1"
+md_iid = "5.0"
+md_version = "2.2.2"
 md_name = "Translator"
 md_description = "Translate text using online translators"
 md_license = "MIT"
@@ -23,11 +23,11 @@ md_lib_dependencies = ["translators"]
 md_maintainers = ["@ManuelSchneid3r"]
 
 
-class Plugin(PluginInstance, TriggerQueryHandler):
+class Plugin(PluginInstance, GeneratorQueryHandler):
 
     def __init__(self):
         PluginInstance.__init__(self)
-        TriggerQueryHandler.__init__(self)
+        GeneratorQueryHandler.__init__(self)
 
         self._translator = self.readConfig('translator', str)
         if self._translator is None:
@@ -46,7 +46,7 @@ class Plugin(PluginInstance, TriggerQueryHandler):
 
     @staticmethod
     def makeIcon():
-        return makeImageIcon(Path(__file__).parent / "google_translate.png")
+        return Icon.image(Path(__file__).parent / "google_translate.png")
 
     @property
     def translator(self):
@@ -77,6 +77,7 @@ class Plugin(PluginInstance, TriggerQueryHandler):
             {
                 'type': 'label',
                 'text': __doc__.strip(),
+                'widget_properties': {'textFormat': 'Qt::MarkdownText'}
             },
             {
                 'type': 'combobox',
@@ -94,58 +95,53 @@ class Plugin(PluginInstance, TriggerQueryHandler):
     def synopsis(self, s):
         return "[[from] to] text"
 
-    def handleTriggerQuery(self, query):
-        stripped = query.string.strip()
-        if stripped:
-            for _ in range(50):
-                sleep(0.01)
-                if not query.isValid:
-                    return
+    def items(self, ctx):
+        query = ctx.query.strip()
+        if not query:
+            return []
 
-            if len(splits := stripped.split(maxsplit=2)) == 3 \
-                    and splits[0] in self.src_languages and splits[1] in self.dst_languages:
-                src, dst, text = splits
-            elif len(splits := stripped.split(maxsplit=1)) == 2 and splits[0] in self.src_languages:
-                src, dst, text = 'auto', splits[0], splits[1]
-            else:
-                src, dst, text = 'auto', self.lang, stripped
+        for _ in range(50):
+            sleep(0.01)
+            if not ctx.isValid:
+                return []
 
-            try:
-                translation = ts.translate_text(query_text=text,
-                                                translator=self.translator,
-                                                from_language=src,
-                                                to_language=dst,
-                                                timeout=5)
+        if len(splits := query.split(maxsplit=2)) == 3 \
+                and splits[0] in self.src_languages and splits[1] in self.dst_languages:
+            src, dst, text = splits
+        elif len(splits := query.split(maxsplit=1)) == 2 and splits[0] in self.src_languages:
+            src, dst, text = 'auto', splits[0], splits[1]
+        else:
+            src, dst, text = 'auto', self.lang, query
 
-                actions = []
-                if havePasteSupport():
-                    actions.append(
-                        Action(
-                            "paste", "Copy to clipboard and paste to front-most window",
-                            lambda t=translation: setClipboardTextAndPaste(t)
-                        )
-                    )
+        try:
+            translation = ts.translate_text(query_text=text,
+                                            translator=self.translator,
+                                            from_language=src,
+                                            to_language=dst,
+                                            timeout=5)
 
-                actions.append(
-                    Action("copy", "Copy to clipboard",
-                           lambda t=translation: setClipboardText(t))
-                )
+            actions = []
+            if havePasteSupport():
+                actions.append(Action("paste", "Copy & Paste", lambda t=translation: setClipboardTextAndPaste(t)))
+            actions.append(Action("copy", "Copy to clipboard", lambda t=translation: setClipboardText(t)))
 
-                query.add(StandardItem(
+            yield [
+                StandardItem(
                     id=self.id(),
                     text=translation,
                     subtext=f"{src.upper()} > {dst.upper()}",
                     icon_factory=Plugin.makeIcon,
                     actions=actions
-                ))
+                )
+            ]
 
-            except Exception as e:
-
-                query.add(StandardItem(
+        except Exception as e:
+            warning(str(e))
+            yield [
+                StandardItem(
                     id=self.id(),
                     text="Error",
                     subtext=str(e),
                     icon_factory=Plugin.makeIcon
-                ))
-
-                warning(str(e))
\ No newline at end of file
+                )
+            ]
