@@ -3,8 +3,8 @@
 
 import albert
 
-md_iid = "4.0"
-md_version = "3.1.1"
+md_iid = "5.0"
+md_version = "3.1.2"
 md_name = "Zeal"
 md_description = "Search in Zeal docs"
 md_license = "MIT"
@@ -17,7 +17,7 @@ def createItem(query: str):
         id=md_name,
         text=md_name,
         subtext=f"Search '{query}' in Zeal",
-        icon_factory=lambda: albert.makeThemeIcon("zeal"),
+        icon_factory=lambda: albert.Icon.theme("zeal"),
         actions=[albert.Action("zeal", "Search in Zeal",
                                lambda q=query: albert.runDetachedProcess(['zeal', q]))]
     )
@@ -37,11 +37,11 @@ class FBH(albert.FallbackHandler):
         return [createItem(s)] if s else []
 
 
-class Plugin(albert.PluginInstance, albert.TriggerQueryHandler):
+class Plugin(albert.PluginInstance, albert.GeneratorQueryHandler):
 
     def __init__(self):
         albert.PluginInstance.__init__(self)
-        albert.TriggerQueryHandler.__init__(self)
+        albert.GeneratorQueryHandler.__init__(self)
         self.fbh = FBH()
 
     def defaultTrigger(self):
@@ -50,6 +50,6 @@ class Plugin(albert.PluginInstance, albert.TriggerQueryHandler):
     def extensions(self):
         return [self, self.fbh]
 
-    def handleTriggerQuery(self, query):
-        if stripped := query.string.strip():
-            query.add(createItem(stripped))
+    def items(self, ctx):
+        if query := ctx.query.strip():
+            yield [createItem(query)]
